@@ -119,7 +119,7 @@ class CreateCluster(Command):
          'schema': argumentschema.KERBEROS_ATTRIBUTES_SCHEMA,
          'help_text': helptext.KERBEROS_ATTRIBUTES}
     ]
-    SYNOPSIS = BasicCommand.FROM_FILE('emr', 'create-cluster-synopsis.rst')
+    SYNOPSIS = BasicCommand.FROM_FILE('emr', 'create-cluster-synopsis.txt')
     EXAMPLES = BasicCommand.FROM_FILE('emr', 'create-cluster-examples.rst')
 
     def _run_main_command(self, parsed_args, parsed_globals):
@@ -344,11 +344,14 @@ class CreateCluster(Command):
 
     def _construct_result(self, run_job_flow_result):
         jobFlowId = None
+        clusterArn = None
         if run_job_flow_result is not None:
             jobFlowId = run_job_flow_result.get('JobFlowId')
+            clusterArn = run_job_flow_result.get('ClusterArn')
 
         if jobFlowId is not None:
-            return {'ClusterId': jobFlowId}
+            return {'ClusterId': jobFlowId,
+                    'ClusterArn': clusterArn }
         else:
             return {}
 
